# Gradiome / Gradio

Gradio is a python library that allows you to place input and output interfaces over trained models to make it easy for you to "play around" with your model. Gradio runs entirely locally using your browser.

To get started understanding gradio, I recommend you go in the following order:
1. Run the Usage.ipynb python notebook
2. Look at the gradio.py code
3. Look at the templates/draw_a_digit.html 

You'll notice that gradio includes both front-end design (in the HTML folder) as well as back-end design (gradio.py). 
